﻿############################################################
# Joins a SharePoint 2013 Farm
############################################################

Add-PSSnapin Microsoft.SharePoint.PowerShell -erroraction SilentlyContinue 

## Settings ##
$configDatabaseName = "SP2013_Farm_SharePoint_Config"
$sqlServer = "SP2013SQL1"
$sqlServerAlias = "SP2013SQL" 
$passphrase = "pass@word1"
$sPassphrase = (ConvertTo-SecureString -String $passphrase -AsPlainText -force)

########################################
# Create the SQL Alias
########################################

$x86 = "HKLM:\Software\Microsoft\MSSQLServer\Client\ConnectTo" 
$x64 = "HKLM:\Software\Wow6432Node\Microsoft\MSSQLServer\Client\ConnectTo"   
 
 
if ((test-path -path $x86) -ne $True)  
{ 
     write-host "$x86 doesn't exist"     
    New-Item $x86  
}  
 
if ((test-path -path $x64) -ne $True)  
{ 
     write-host "$x64 doesn't exist"     
    New-Item $x64  
}    
 
$TCPAlias = "DBMSSOCN," + $SQLServer 
 
New-ItemProperty -Path $x86 -Name $sqlServerAlias -PropertyType String -Value $TCPAlias  
New-ItemProperty -Path $x64 -Name $sqlServerAlias -PropertyType String -Value $TCPAlias 

########################################
# Create the farm
########################################
Write-Output "Connecting to the configuration database $configDatabaseName"

# psconfig -cmd upgrade -inplace b2b -wait -force
Connect-SPConfigurationDatabase -DatabaseServer $sqlServerAlias -DatabaseName $configDatabaseName -Passphrase $sPassphrase

# Check to make sure the farm exists and is running. if not, end the script
$farm = Get-SPFarm
if (!$farm -or $farm.Status -ne "Online") {
	Write-Output "Farm was not connected or is not running"
	exit
}

# Perform the config wizard tasks
Write-Output "Initialize security"
Initialize-SPResourceSecurity

Write-Output "Install services"
Install-SPService

Write-Output "Register features"
Install-SPFeature -AllExistingFeatures

New-ItemProperty HKLM:\System\CurrentControlSet\Control\Lsa -Name "DisableLoopbackCheck" -value "1" -PropertyType dword
