﻿Import-Module ActiveDirectory

function createUser
{
    param ([string] $ou, [string] $firstName, [string] $lastName, [string] $password, [string] $emailDomain)
    
    $userName = $firstName + "." + $lastName
    $fullName = $firstName + " " + $lastName
    $emailAddress = $username + "@" + $emailDomain
    New-ADUser -SamAccountName $userName -Name $fullName -DisplayName $fullName -GivenName $firstName -Surname $lastName -Path $ou -ChangePasswordAtLogon $false -AccountPassword (ConvertTo-SecureString -AsPlainText -String $password -Force) -Description $fullName -Enabled $true -EmailAddress $emailAddress -PasswordNeverExpires $true -UserPrincipalName $emailAddress
}

function createServiceUser
{
    param ([string] $ou, [string] $userName, [string] $password, [string] $emailDomain)
    
    $emailAddress = $username + "@" + $emailDomain
    New-ADUser -SamAccountName $userName -Name $userName -DisplayName $fullName -Path $ou -ChangePasswordAtLogon $false -AccountPassword (ConvertTo-SecureString -AsPlainText -String $password -Force) -Description $userName -Enabled $true -EmailAddress $emailAddress -PasswordNeverExpires $true -UserPrincipalName $emailAddress
}

$domain = [ADSI] "LDAP://dc=sp2013,dc=test"

$ouServices = $domain.Create("organizationalUnit", "ou=Services")
$ouServices.SetInfo()

$ouUserProfiles = $domain.Create("organizationalUnit", "ou=SharePoint Users")
$ouUserProfiles.SetInfo()

$ouUserProfilesDevLeap = $ouUserProfiles.Create("organizationalUnit", "ou=DevLeap")
$ouUserProfilesDevLeap.SetInfo()

$ouUserProfilesDevLead = $ouUserProfiles.Create("organizationalUnit", "ou=DevLead")
$ouUserProfilesDevLead.SetInfo()

$ouUserProfilesEmployees = $ouUserProfiles.Create("organizationalUnit", "ou=Employees")
$ouUserProfilesEmployees.SetInfo()

$services = [ADSI] "LDAP://ou=Services,dc=sp2013,dc=test"
$devleap = [ADSI] "LDAP://ou=DevLeap,ou=SharePoint Users,dc=sp2013,dc=test"
$devlead = [ADSI] "LDAP://ou=DevLead,ou=SharePoint Users,dc=sp2013,dc=test"
$employees = [ADSI] "LDAP://ou=Employees,ou=SharePoint Users,dc=sp2013,dc=test"

$fakePassword = "Pass@w0rd!"
$emailDomain = "sp2013.test"

createServiceUser -ou $services.distinguishedName -userName "SPFarm" -password $fakePassword -emailDomain $emailDomain
createServiceUser -ou $services.distinguishedName -userName "SPService" -password $fakePassword -emailDomain $emailDomain
createServiceUser -ou $services.distinguishedName -userName "SPContent" -password $fakePassword -emailDomain $emailDomain
createServiceUser -ou $services.distinguishedName -userName "SPSearch" -password $fakePassword -emailDomain $emailDomain
createServiceUser -ou $services.distinguishedName -userName "SPUPS" -password $fakePassword -emailDomain $emailDomain
createServiceUser -ou $services.distinguishedName -userName "SQLService" -password $fakePassword -emailDomain $emailDomain
createServiceUser -ou $services.distinguishedName -userName "SQLAgent" -password $fakePassword -emailDomain $emailDomain
createServiceUser -ou $services.distinguishedName -userName "SQLReporting" -password $fakePassword -emailDomain $emailDomain

createUser -ou $devleap.distinguishedName -firstName "Paolo" -lastName "Pialorsi" -password $fakePassword -emailDomain $emailDomain
createUser -ou $devleap.distinguishedName -firstName "Marco" -lastName "Russo" -password $fakePassword -emailDomain $emailDomain
createUser -ou $devleap.distinguishedName -firstName "Roberto" -lastName "Brunetti" -password $fakePassword -emailDomain $emailDomain
createUser -ou $devleap.distinguishedName -firstName "Luca" -lastName "Regnicoli" -password $fakePassword -emailDomain $emailDomain

createUser -ou $devlead.distinguishedName -firstName "Jessica" -lastName "Faustinelli" -password $fakePassword -emailDomain $emailDomain
createUser -ou $devlead.distinguishedName -firstName "Guido" -lastName "Zambarda" -password $fakePassword -emailDomain $emailDomain
createUser -ou $devlead.distinguishedName -firstName "Cristian" -lastName "Civera" -password $fakePassword -emailDomain $emailDomain
createUser -ou $devlead.distinguishedName -firstName "Vanni" -lastName "Boncinelli" -password $fakePassword -emailDomain $emailDomain
createUser -ou $devlead.distinguishedName -firstName "Katia" -lastName "Egiziano" -password $fakePassword -emailDomain $emailDomain
createUser -ou $devlead.distinguishedName -firstName "Rosanna" -lastName "Coradi" -password $fakePassword -emailDomain $emailDomain

$c = 11
 
do {
    $firstName = "fn" + $c
    $lastName = "ln" + $c
    createUser -ou $employees.distinguishedName -firstName $firstName -lastName $lastName -password $fakePassword -emailDomain $emailDomain
    $c++
}
while ($c -le 500)
